@@ -1,4 +1,7 @@
 //! Subcommand modules for the `rgr` binary.
 
+pub mod count;
+pub mod field;
 pub mod merge;
 pub mod replace;
+pub mod runlist;
