@@ -3,13 +3,11 @@
 pub mod combine;
 pub mod compare;
 pub mod convert;
-pub mod count;
 pub mod cover;
 pub mod coverage;
 pub mod genome;
 pub mod gff;
 pub mod merge;
-pub mod range;
 pub mod some;
 pub mod span;
 pub mod split;
