@@ -499,7 +499,7 @@ fn command_cover() -> Result<(), Box<dyn std::error::Error>> {
     let mut cmd = Command::cargo_bin("spanr")?;
     let output = cmd
         .arg("cover")
-        .arg("tests/spanr/S288c.ranges")
+        .arg("tests/spanr/S288c.rg")
         .output()
         .unwrap();
     let stdout = String::from_utf8(output.stdout).unwrap();
@@ -513,7 +513,7 @@ fn command_cover() -> Result<(), Box<dyn std::error::Error>> {
     let mut cmd = Command::cargo_bin("spanr")?;
     let output = cmd
         .arg("cover")
-        .arg("tests/spanr/dazzname.ranges")
+        .arg("tests/spanr/dazzname.rg")
         .output()
         .unwrap();
     let stdout = String::from_utf8(output.stdout).unwrap();
@@ -530,7 +530,7 @@ fn command_coverage() -> Result<(), Box<dyn std::error::Error>> {
     let mut cmd = Command::cargo_bin("spanr")?;
     let output = cmd
         .arg("coverage")
-        .arg("tests/spanr/S288c.ranges")
+        .arg("tests/spanr/S288c.rg")
         .arg("-m")
         .arg("2")
         .output()
@@ -550,7 +550,7 @@ fn command_coverage_detailed() -> Result<(), Box<dyn std::error::Error>> {
     let mut cmd = Command::cargo_bin("spanr")?;
     let output = cmd
         .arg("coverage")
-        .arg("tests/spanr/S288c.ranges")
+        .arg("tests/spanr/S288c.rg")
         .arg("-m")
         .arg("1")
         .arg("-d")
@@ -646,86 +646,3 @@ fn command_convert() -> Result<(), Box<dyn std::error::Error>> {
 
     Ok(())
 }
-
-#[test]
-fn command_range() -> Result<(), Box<dyn std::error::Error>> {
-    let mut cmd = Command::cargo_bin("spanr")?;
-    let output = cmd
-        .arg("range")
-        .arg("tests/spanr/intergenic.yml")
-        .arg("tests/spanr/S288c.ranges")
-        .arg("--op")
-        .arg("overlap")
-        .output()
-        .unwrap();
-    let stdout = String::from_utf8(output.stdout).unwrap();
-
-    assert_eq!(stdout.lines().count(), 2);
-    assert!(!stdout.contains("S288c"));
-    assert!(stdout.contains("21294-22075"));
-
-    let mut cmd = Command::cargo_bin("spanr")?;
-    let output = cmd
-        .arg("range")
-        .arg("tests/spanr/intergenic.yml")
-        .arg("tests/spanr/S288c.ranges")
-        .arg("--op")
-        .arg("non-overlap")
-        .output()
-        .unwrap();
-    let stdout = String::from_utf8(output.stdout).unwrap();
-
-    assert_eq!(stdout.lines().count(), 4);
-    assert!(stdout.contains("S288c"));
-    assert!(!stdout.contains("21294-22075"));
-
-    let mut cmd = Command::cargo_bin("spanr")?;
-    let output = cmd
-        .arg("range")
-        .arg("tests/spanr/intergenic.yml")
-        .arg("tests/spanr/S288c.ranges")
-        .arg("--op")
-        .arg("superset")
-        .output()
-        .unwrap();
-    let stdout = String::from_utf8(output.stdout).unwrap();
-
-    assert_eq!(stdout.lines().count(), 2);
-    assert!(!stdout.contains("S288c"));
-    assert!(stdout.contains("21294-22075"));
-
-    Ok(())
-}
-
-#[test]
-fn command_range_invalid() -> Result<(), Box<dyn std::error::Error>> {
-    let mut cmd = Command::cargo_bin("spanr")?;
-    cmd.arg("range")
-        .arg("tests/spanr/intergenic.yml")
-        .arg("tests/spanr/S288c.ranges")
-        .arg("--op")
-        .arg("invalid");
-    cmd.assert()
-        .failure()
-        .stderr(predicate::str::contains("Invalid Range Op"));
-
-    Ok(())
-}
-
-#[test]
-fn command_count() -> Result<(), Box<dyn std::error::Error>> {
-    let mut cmd = Command::cargo_bin("spanr")?;
-    let output = cmd
-        .arg("count")
-        .arg("tests/spanr/S288c.ranges")
-        .arg("tests/spanr/S288c.ranges")
-        .output()
-        .unwrap();
-    let stdout = String::from_utf8(output.stdout).unwrap();
-
-    assert_eq!(stdout.lines().count(), 6);
-    assert!(stdout.contains("I:1-100\t2"));
-    assert!(stdout.contains("21294-22075\t1"));
-
-    Ok(())
-}
